aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar Maxime Dénès <mail@maximedenes.fr>2017-10-20 11:14:09 +0200
committerGravatar Maxime Dénès <mail@maximedenes.fr>2017-10-20 11:14:09 +0200
commit62684a5c817da4afc2a7dac6ece03facabdd5fe4 (patch)
tree224a8c854062bcd75add73f0a95a40223239acd1
parent025a60b92618e4a8f10ab9704a38949383c87efa (diff)
parent8df509882d5b0954b40b576c4e9d3b3f742c619d (diff)
Merge PR #5984: CI: build lambdaRust (which depends on Iris) rather than just Iris
-rw-r--r--.gitlab-ci.yml2
-rw-r--r--.travis.yml2
-rw-r--r--Makefile.ci2
-rw-r--r--dev/ci/ci-basic-overlay.sh3
-rwxr-xr-xdev/ci/ci-iris-lambda-rust.sh (renamed from dev/ci/ci-iris-coq.sh)27
5 files changed, 26 insertions, 10 deletions
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index d2e335d45..1814aaff1 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -311,7 +311,7 @@ ci-hott:
<<: *ci-template-vars
EXTRA_PACKAGES: "$TIMING_PACKAGES autoconf"
-ci-iris-coq:
+ci-iris-lambda-rust:
<<: *ci-template
ci-math-classes:
diff --git a/.travis.yml b/.travis.yml
index c38038452..196f4b22a 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -50,7 +50,7 @@ env:
- TEST_TARGET="ci-flocq TIMED=1"
- TEST_TARGET="ci-formal-topology TIMED=1"
- TEST_TARGET="ci-hott TIMED=1"
- - TEST_TARGET="ci-iris-coq TIMED=1"
+ - TEST_TARGET="ci-iris-lambda-rust TIMED=1"
- TEST_TARGET="ci-math-classes TIMED=1"
- TEST_TARGET="ci-math-comp TIMED=1"
- TEST_TARGET="ci-sf TIMED=1"
diff --git a/Makefile.ci b/Makefile.ci
index b5a26d96e..54ebf211f 100644
--- a/Makefile.ci
+++ b/Makefile.ci
@@ -11,7 +11,7 @@ CI_TARGETS=ci-all \
ci-formal-topology \
ci-geocoq \
ci-hott \
- ci-iris-coq \
+ ci-iris-lambda-rust \
ci-math-classes \
ci-math-comp \
ci-metacoq \
diff --git a/dev/ci/ci-basic-overlay.sh b/dev/ci/ci-basic-overlay.sh
index 43525dcd4..545846da5 100644
--- a/dev/ci/ci-basic-overlay.sh
+++ b/dev/ci/ci-basic-overlay.sh
@@ -43,6 +43,9 @@
: ${Iris_CI_BRANCH:=master}
: ${Iris_CI_GITURL:=https://gitlab.mpi-sws.org/FP/iris-coq.git}
+: ${lambdaRust_CI_BRANCH:=master}
+: ${lambdaRust_CI_GITURL:=https://gitlab.mpi-sws.org/FP/LambdaRust-coq.git}
+
########################################################################
# HoTT
########################################################################
diff --git a/dev/ci/ci-iris-coq.sh b/dev/ci/ci-iris-lambda-rust.sh
index c49b6ed9c..cf24d202d 100755
--- a/dev/ci/ci-iris-coq.sh
+++ b/dev/ci/ci-iris-lambda-rust.sh
@@ -4,25 +4,38 @@ ci_dir="$(dirname "$0")"
source ${ci_dir}/ci-common.sh
stdpp_CI_DIR=${CI_BUILD_DIR}/coq-stdpp
-
Iris_CI_DIR=${CI_BUILD_DIR}/iris-coq
+lambdaRust_CI_DIR=${CI_BUILD_DIR}/lambdaRust
install_ssreflect
# Add or update the opam repo we need for dependency resolution
opam repo add iris-dev https://gitlab.mpi-sws.org/FP/opam-dev.git -p 0 || opam update iris-dev
-# Setup Iris first, extract required version of std++
-git_checkout ${Iris_CI_BRANCH} ${Iris_CI_GITURL} ${Iris_CI_DIR}
-stdpp_VERSION=$(cat ${Iris_CI_DIR}/opam | fgrep coq-stdpp | egrep 'dev\.([0-9.-]+)' -o)
+# Setup lambdaRust first
+git_checkout ${lambdaRust_CI_BRANCH} ${lambdaRust_CI_GITURL} ${lambdaRust_CI_DIR}
+
+# Extract required version of Iris
+Iris_VERSION=$(cat ${lambdaRust_CI_DIR}/opam | fgrep coq-iris | egrep 'dev\.([0-9.-]+)' -o)
+Iris_URL=$(opam show coq-iris.$Iris_VERSION -f upstream-url)
+read -a Iris_URL_PARTS <<< $(echo $Iris_URL | tr '#' ' ')
+
+# Setup Iris
+git_checkout ${Iris_CI_BRANCH} ${Iris_URL_PARTS[0]} ${Iris_CI_DIR} ${Iris_URL_PARTS[1]}
-# Ask opam where to get this std++, separating at the #
+# Extract required version of std++
+stdpp_VERSION=$(cat ${Iris_CI_DIR}/opam | fgrep coq-stdpp | egrep 'dev\.([0-9.-]+)' -o)
stdpp_URL=$(opam show coq-stdpp.$stdpp_VERSION -f upstream-url)
read -a stdpp_URL_PARTS <<< $(echo $stdpp_URL | tr '#' ' ')
# Setup std++
git_checkout ${stdpp_CI_BRANCH} ${stdpp_URL_PARTS[0]} ${stdpp_CI_DIR} ${stdpp_URL_PARTS[1]}
+
+# Build std++
( cd ${stdpp_CI_DIR} && make && make install )
-# Build iris now
-( cd ${Iris_CI_DIR} && make )
+# Build iris
+( cd ${Iris_CI_DIR} && make && make install )
+
+# Build lambdaRust
+( cd ${lambdaRust_CI_DIR} && make && make install )